@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2011 Motorola Mobility, Inc.  All rights reserved.
+ * Copyright (c) 2011 Motorola Mobility, Inc. All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without modification,
  * are permitted provided that the following conditions are met:
@@ -28,9 +28,6 @@
  * SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  */
 
-#if !defined(__WEBKIT_H_INSIDE__) && !defined(WEBKIT2_COMPILATION)
-#error "Only <wpe/webkit.h> can be included directly."
-#endif
 
 #ifndef WebKitSettings_h
 #define WebKitSettings_h
@@ -41,33 +38,9 @@
 G_BEGIN_DECLS
 
 #define WEBKIT_TYPE_SETTINGS            (webkit_settings_get_type())
-#define WEBKIT_SETTINGS(obj)            (G_TYPE_CHECK_INSTANCE_CAST((obj), WEBKIT_TYPE_SETTINGS, WebKitSettings))
-#define WEBKIT_SETTINGS_CLASS(klass)    (G_TYPE_CHECK_CLASS_CAST((klass),  WEBKIT_TYPE_SETTINGS, WebKitSettingsClass))
-#define WEBKIT_IS_SETTINGS(obj)         (G_TYPE_CHECK_INSTANCE_TYPE((obj), WEBKIT_TYPE_SETTINGS))
-#define WEBKIT_IS_SETTINGS_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE((klass),  WEBKIT_TYPE_SETTINGS))
-#define WEBKIT_SETTINGS_GET_CLASS(obj)  (G_TYPE_INSTANCE_GET_CLASS((obj),  WEBKIT_TYPE_SETTINGS, WebKitSettingsClass))
 
-typedef struct _WebKitSettings WebKitSettings;
-typedef struct _WebKitSettingsClass WebKitSettingsClass;
-typedef struct _WebKitSettingsPrivate WebKitSettingsPrivate;
+WEBKIT_DECLARE_FINAL_TYPE (WebKitSettings, webkit_settings, WEBKIT, SETTINGS, GObject)
 
-struct _WebKitSettings {
-    GObject parent_instance;
-
-    WebKitSettingsPrivate *priv;
-};
-
-struct _WebKitSettingsClass {
-    GObjectClass parent_class;
-
-    void (*_webkit_reserved0) (void);
-    void (*_webkit_reserved1) (void);
-    void (*_webkit_reserved2) (void);
-    void (*_webkit_reserved3) (void);
-};
-
-WEBKIT_API GType
-webkit_settings_get_type(void);
 
 WEBKIT_API WebKitSettings *
 webkit_settings_new                                            (void);
@@ -90,17 +63,17 @@ WEBKIT_API void
 webkit_settings_set_auto_load_images                           (WebKitSettings *settings,
                                                                 gboolean        enabled);
 
-WEBKIT_API gboolean
+WEBKIT_DEPRECATED gboolean
 webkit_settings_get_load_icons_ignoring_image_load_setting     (WebKitSettings *settings);
 
-WEBKIT_API void
+WEBKIT_DEPRECATED void
 webkit_settings_set_load_icons_ignoring_image_load_setting     (WebKitSettings *settings,
                                                                 gboolean        enabled);
 
-WEBKIT_API gboolean
+WEBKIT_DEPRECATED gboolean
 webkit_settings_get_enable_offline_web_application_cache       (WebKitSettings *settings);
 
-WEBKIT_API void
+WEBKIT_DEPRECATED void
 webkit_settings_set_enable_offline_web_application_cache       (WebKitSettings *settings,
                                                                 gboolean        enabled);
 
@@ -117,33 +90,6 @@ webkit_settings_get_enable_html5_database                      (WebKitSettings *
 WEBKIT_API void
 webkit_settings_set_enable_html5_database                      (WebKitSettings *settings,
                                                                 gboolean        enabled);
-WEBKIT_API gboolean
-webkit_settings_get_enable_xss_auditor                         (WebKitSettings *settings);
-
-WEBKIT_API void
-webkit_settings_set_enable_xss_auditor                         (WebKitSettings *settings,
-                                                                gboolean        enabled);
-
-WEBKIT_API gboolean
-webkit_settings_get_enable_frame_flattening                    (WebKitSettings *settings);
-
-WEBKIT_API void
-webkit_settings_set_enable_frame_flattening                    (WebKitSettings *settings,
-                                                                gboolean        enabled);
-
-WEBKIT_API gboolean
-webkit_settings_get_enable_plugins                             (WebKitSettings *settings);
-
-WEBKIT_API void
-webkit_settings_set_enable_plugins                             (WebKitSettings *settings,
-                                                                gboolean        enabled);
-
-WEBKIT_API gboolean
-webkit_settings_get_enable_java                                (WebKitSettings *settings);
-
-WEBKIT_API void
-webkit_settings_set_enable_java                                (WebKitSettings *settings,
-                                                                gboolean        enabled);
 
 WEBKIT_API gboolean
 webkit_settings_get_javascript_can_open_windows_automatically  (WebKitSettings *settings);
@@ -152,10 +98,10 @@ WEBKIT_API void
 webkit_settings_set_javascript_can_open_windows_automatically  (WebKitSettings *settings,
                                                                 gboolean        enabled);
 
-WEBKIT_API gboolean
+WEBKIT_DEPRECATED gboolean
 webkit_settings_get_enable_hyperlink_auditing                  (WebKitSettings *settings);
 
-WEBKIT_API void
+WEBKIT_DEPRECATED void
 webkit_settings_set_enable_hyperlink_auditing                  (WebKitSettings *settings,
                                                                 gboolean        enabled);
 
@@ -236,6 +182,7 @@ WEBKIT_API void
 webkit_settings_set_default_charset                            (WebKitSettings *settings,
                                                                 const gchar    *default_charset);
 
+
 WEBKIT_API gboolean
 webkit_settings_get_enable_developer_extras                    (WebKitSettings *settings);
 
@@ -257,10 +204,10 @@ WEBKIT_API void
 webkit_settings_set_enable_tabs_to_links                       (WebKitSettings *settings,
                                                                 gboolean        enabled);
 
-WEBKIT_API gboolean
+WEBKIT_DEPRECATED gboolean
 webkit_settings_get_enable_dns_prefetching                     (WebKitSettings *settings);
 
-WEBKIT_API void
+WEBKIT_DEPRECATED void
 webkit_settings_set_enable_dns_prefetching                     (WebKitSettings *settings,
                                                                 gboolean        enabled);
 
@@ -372,11 +319,12 @@ WEBKIT_API void
 webkit_settings_set_enable_smooth_scrolling                    (WebKitSettings *settings,
                                                                 gboolean        enabled);
 
+
 WEBKIT_API gboolean
-webkit_settings_get_enable_accelerated_2d_canvas               (WebKitSettings *settings);
+webkit_settings_get_enable_2d_canvas_acceleration              (WebKitSettings *settings);
 
 WEBKIT_API void
-webkit_settings_set_enable_accelerated_2d_canvas               (WebKitSettings *settings,
+webkit_settings_set_enable_2d_canvas_acceleration              (WebKitSettings *settings,
                                                                 gboolean        enabled);
 
 WEBKIT_API gboolean
@@ -449,6 +397,7 @@ WEBKIT_API void
 webkit_settings_set_allow_top_navigation_to_data_urls          (WebKitSettings *settings,
                                                                 gboolean        allowed);
 
+
 WEBKIT_API gboolean
 webkit_settings_get_enable_javascript_markup                   (WebKitSettings *settings);
 
@@ -470,6 +419,54 @@ WEBKIT_API void
 webkit_settings_set_media_content_types_requiring_hardware_support (WebKitSettings *settings,
                                                                     const gchar *content_types);
 
+WEBKIT_API gboolean
+webkit_settings_get_enable_webrtc                              (WebKitSettings *settings);
+
+WEBKIT_API void
+webkit_settings_set_enable_webrtc                              (WebKitSettings *settings,
+                                                                gboolean enabled);
+
+WEBKIT_API gboolean
+webkit_settings_get_disable_web_security                       (WebKitSettings *settings);
+
+WEBKIT_API void
+webkit_settings_set_disable_web_security                       (WebKitSettings *settings,
+                                                                gboolean        disabled);
+
+typedef struct _WebKitFeature WebKitFeature;
+typedef struct _WebKitFeatureList WebKitFeatureList;
+
+WEBKIT_API void
+webkit_settings_set_feature_enabled                            (WebKitSettings *settings,
+                                                                WebKitFeature  *feature,
+                                                                gboolean        enabled);
+
+WEBKIT_API gboolean
+webkit_settings_get_feature_enabled                            (WebKitSettings *settings,
+                                                                WebKitFeature  *feature);
+
+WEBKIT_API WebKitFeatureList *
+webkit_settings_get_all_features                               (void);
+
+WEBKIT_API WebKitFeatureList *
+webkit_settings_get_experimental_features                      (void);
+
+WEBKIT_API WebKitFeatureList *
+webkit_settings_get_development_features                       (void);
+
+WEBKIT_API gboolean
+webkit_settings_apply_from_key_file                            (WebKitSettings  *settings,
+                                                                GKeyFile        *key_file,
+                                                                const gchar     *group_name,
+                                                                GError         **error);
+
+WEBKIT_API const gchar*
+webkit_settings_get_webrtc_udp_ports_range                     (WebKitSettings *settings);
+
+WEBKIT_API void
+webkit_settings_set_webrtc_udp_ports_range                     (WebKitSettings *settings,
+                                                                const gchar    *udp_port_range);
+
 G_END_DECLS
 
 #endif /* WebKitSettings_h */
